summaryrefslogtreecommitdiffstats
path: root/kmail/kmedit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmedit.cpp')
-rw-r--r--kmail/kmedit.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmail/kmedit.cpp b/kmail/kmedit.cpp
index 6fdc3352..46fd2a83 100644
--- a/kmail/kmedit.cpp
+++ b/kmail/kmedit.cpp
@@ -112,7 +112,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
&& ( col >= int( bot ) ) ) {
// The cursor position might have changed unpredictably if there was selected
- // text which got replaced by a new line, so we query it again:
+ // text which got tqreplaced by a new line, so we query it again:
getCursorPosition( &line, &col );
TQString newLine = text( line );
// remove leading white space from the new line and instead
@@ -122,7 +122,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
&& newLine[leadingWhiteSpaceCount].isSpace() ) {
++leadingWhiteSpaceCount;
}
- newLine = newLine.replace( 0, leadingWhiteSpaceCount,
+ newLine = newLine.tqreplace( 0, leadingWhiteSpaceCount,
lineText.left( bot ) );
removeParagraph( line );
insertParagraph( newLine, line );
@@ -148,7 +148,7 @@ void KMEdit::contentsDropEvent(TQDropEvent *e)
TQBuffer serNumBuffer(serNums);
serNumBuffer.open(IO_ReadOnly);
TQDataStream serNumStream(&serNumBuffer);
- Q_UINT32 serNum;
+ TQ_UINT32 serNum;
KMFolder *folder = 0;
int idx;
TQPtrList<KMMsgBase> messageList;
@@ -169,7 +169,7 @@ void KMEdit::contentsDropEvent(TQDropEvent *e)
command->start();
}
else if( e->provides("image/png") ) {
- emit attachPNGImageData(e->encodedData("image/png"));
+ emit attachPNGImageData(e->tqencodedData("image/png"));
}
else if( KURLDrag::canDecode( e ) ) {
KURL::List urlList;
@@ -383,7 +383,7 @@ KMSyntaxHighter::KMSyntaxHighter( TQTextEdit *textEdit,
bool KMSyntaxHighter::isMisspelled( const TQString &word )
{
- if ( mIgnoredWords.contains( word ) ) {
+ if ( mIgnoredWords.tqcontains( word ) ) {
return false;
}
else {
@@ -440,8 +440,8 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
(*mExtEditorTempFile->textStream()) << text();
mExtEditorTempFile->close();
- // replace %f in the system line
- sysLine.replace( "%f", mExtEditorTempFile->name() );
+ // tqreplace %f in the system line
+ sysLine.tqreplace( "%f", mExtEditorTempFile->name() );
mExtEditorProcess = new KProcess();
mExtEditorProcess->setUseShell( true );
sysLine += " ";
@@ -454,7 +454,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
TQT_SLOT(slotExternalEditorDone(KProcess*)));
if (!mExtEditorProcess->start())
{
- KMessageBox::error( topLevelWidget(),
+ KMessageBox::error( tqtopLevelWidget(),
i18n("Unable to start external editor.") );
killExternalEditor();
} else {
@@ -503,7 +503,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
lastSpace = paraText.length();
TQString word = paraText.mid( firstSpace, lastSpace - firstSpace );
//Continue if this word was misspelled
- if( !word.isEmpty() && mReplacements.contains( word ) )
+ if( !word.isEmpty() && mReplacements.tqcontains( word ) )
{
KPopupMenu p;
@@ -607,7 +607,7 @@ void KMEdit::slotExternalEditorTempFileChanged( const TQString & fileName ) {
insertLine(TQString::fromLocal8Bit(KPIM::kFileToString( fileName, true, false )), -1);
setAutoUpdate(true);
- repaint();
+ tqrepaint();
}
void KMEdit::slotExternalEditorDone( KProcess * proc ) {
@@ -627,7 +627,7 @@ void KMEdit::killExternalEditor() {
bool KMEdit::checkExternalEditorFinished() {
if ( !mExtEditorProcess )
return true;
- switch ( KMessageBox::warningYesNoCancel( topLevelWidget(),
+ switch ( KMessageBox::warningYesNoCancel( tqtopLevelWidget(),
i18n("The external editor is still running.\n"
"Abort the external editor or leave it open?"),
i18n("External Editor"),
@@ -870,7 +870,7 @@ void KMEdit::slotSpellResult(const TQString &s)
void KMEdit::slotSpellDone()
{
kdDebug(5006)<<" void KMEdit::slotSpellDone()\n";
- KSpell::spellStatus status = mKSpellForDialog->status();
+ KSpell::spelltqStatus status = mKSpellForDialog->status();
delete mKSpellForDialog;
mKSpellForDialog = 0;
@@ -880,7 +880,7 @@ void KMEdit::slotSpellDone()
mComposer->sujectLineWidget()->deselect();
if (status == KSpell::Error)
{
- KMessageBox::sorry( topLevelWidget(),
+ KMessageBox::sorry( tqtopLevelWidget(),
i18n("ISpell/Aspell could not be started. Please "
"make sure you have ISpell or Aspell properly "
"configured and in your PATH.") );
@@ -889,7 +889,7 @@ void KMEdit::slotSpellDone()
else if (status == KSpell::Crashed)
{
spellcheck_stop();
- KMessageBox::sorry( topLevelWidget(),
+ KMessageBox::sorry( tqtopLevelWidget(),
i18n("ISpell/Aspell seems to have crashed.") );
emit spellcheck_done( KS_CANCEL );
}
@@ -898,7 +898,7 @@ void KMEdit::slotSpellDone()
if( mSpellLineEdit )
spellcheck();
else if( !mComposer->subjectTextWasSpellChecked() && status == KSpell::FinishedNoMisspellingsEncountered )
- KMessageBox::information( topLevelWidget(),
+ KMessageBox::information( tqtopLevelWidget(),
i18n("No misspellings encountered.") );
}
}